==> org.opennms.features.wsman-19.0.0-20161104.055659-272-sources.jar: org/opennms/netmgt/dao/jaxb/WSManConfigDaoJaxb.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2010-2016 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2016 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.dao.jaxb;

import java.net.InetAddress;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.Objects;

import org.opennms.core.utils.IPLike;
import org.opennms.core.utils.InetAddressUtils;
import org.opennms.core.wsman.WSManEndpoint;
import org.opennms.core.wsman.WSManVersion;
import org.opennms.core.xml.AbstractJaxbConfigDao;
import org.opennms.netmgt.config.wsman.Definition;
import org.opennms.netmgt.config.wsman.Range;
import org.opennms.netmgt.config.wsman.WsmanAgentConfig;
import org.opennms.netmgt.config.wsman.WsmanConfig;
import org.opennms.netmgt.dao.WSManConfigDao;

public class WSManConfigDaoJaxb extends AbstractJaxbConfigDao<WsmanConfig, WsmanConfig> implements WSManConfigDao {
    private static final String DEFAULT_PROTOCOL = "http";
    private static final String DEFAULT_PATH = "/wsman";

    public WSManConfigDaoJaxb() {
        super(WsmanConfig.class, "WS-Man Configuration");
    }

    @Override
    public WsmanConfig getConfig() {
        return getContainer().getObject();
    }

    @Override
    public WsmanAgentConfig getConfig(InetAddress agentInetAddress) {
        Objects.requireNonNull(agentInetAddress);

        for (Definition def : getConfig().getDefinition()) {
            // Check the specifics first
            for (String saddr : def.getSpecific()) {
                InetAddress addr = InetAddressUtils.addr(saddr);
                if (addr.equals(agentInetAddress)) {
                    return def;
                }
            }

            // Check the ranges
            for (Range rng : def.getRange()) {
                if (InetAddressUtils.isInetAddressInRange(InetAddressUtils.str(agentInetAddress), rng.getBegin(), rng.getEnd())) {
                    return def;
                }
            }

            // Check the matching IP expressions
            for (String ipMatch : def.getIpMatch()) {
                if (IPLike.matches(InetAddressUtils.str(agentInetAddress), ipMatch)) {
                    return def;
                }
            }
        }

        // No definition references the given agent address, use the defaults
        return getConfig();
    }

    @Override
    public WSManEndpoint getEndpoint(InetAddress agentInetAddress) {
        return getEndpoint(getConfig(agentInetAddress), agentInetAddress);
    }

    @Override
    public WSManEndpoint getEndpoint(WsmanAgentConfig agentConfig, InetAddress agentInetAddress) {
        Objects.requireNonNull(agentConfig, "agentConfig argument");
        Objects.requireNonNull(agentInetAddress, "agentInetAddress argument");
        URL url;
        try {
            String protocol = DEFAULT_PROTOCOL;
            if (agentConfig.isSsl()!= null) {
                protocol = agentConfig.isSsl() ? "https" : "http";
            }

            String port = "";
            if (agentConfig.getPort() != null) {
                port = String.format(":%d", agentConfig.getPort());
            }

            String path = DEFAULT_PATH;
            if (agentConfig.getPath() != null) {
                path = agentConfig.getPath();
            }
            // Prepend a forward slash if missing
            if (!path.startsWith("/")) {
                path = "/" + path;
            }

            String host = agentInetAddress.getHostAddress();
            if (agentConfig.isGssAuth()!=null && agentConfig.isGssAuth()) {
                // Always use the canonical host name when using GSS authentication
                host = agentInetAddress.getCanonicalHostName();
            }

            url = new URL(String.format("%s://%s%s%s", protocol, host, port, path));
        } catch (MalformedURLException e) {
            throw new RuntimeException("Invalid endpoint URL: " + e.getMessage());
        }

        final WSManEndpoint.Builder builder = new WSManEndpoint.Builder(url)
                .withServerVersion(WSManVersion.WSMAN_1_0);
        if (agentConfig.getUsername() != null && agentConfig.getPassword() != null) {
            builder.withBasicAuth(agentConfig.getUsername(), agentConfig.getPassword());
        }
        if (agentConfig.isGssAuth() != null && agentConfig.isGssAuth()) {
            builder.withGSSAuth();
        }
        if (agentConfig.getMaxElements() != null) {
            builder.withMaxElements(agentConfig.getMaxElements());
        }
        if (agentConfig.isStrictSsl() != null) {
            builder.withStrictSSL(false);
        }
        if (agentConfig.getTimeout() != null) {
            builder.withConnectionTimeout(agentConfig.getTimeout())
                   .withReceiveTimeout(agentConfig.getTimeout());
        }
        return builder.build();
    }

    @Override
    protected WsmanConfig translateConfig(WsmanConfig config) {
        return config;
    }
}

==> org.opennms.features.wsman-21.1.0-20190525.025133-69-sources.jar: org/opennms/netmgt/dao/jaxb/WSManConfigDaoJaxb.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2010-2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.dao.jaxb;

import java.net.InetAddress;
import java.util.Objects;

import org.opennms.core.utils.IPLike;
import org.opennms.core.utils.InetAddressUtils;
import org.opennms.core.wsman.WSManEndpoint;
import org.opennms.core.xml.AbstractJaxbConfigDao;
import org.opennms.netmgt.config.wsman.Definition;
import org.opennms.netmgt.config.wsman.Range;
import org.opennms.netmgt.config.wsman.WsmanConfig;
import org.opennms.netmgt.dao.WSManConfigDao;

public class WSManConfigDaoJaxb extends AbstractJaxbConfigDao<WsmanConfig, WsmanConfig> implements WSManConfigDao {

    public WSManConfigDaoJaxb() {
        super(WsmanConfig.class, "WS-Man Configuration");
    }

    @Override
    public WsmanConfig getConfig() {
        return getContainer().getObject();
    }

    @Override
    public Definition getAgentConfig(InetAddress agentInetAddress) {
        Objects.requireNonNull(agentInetAddress);

        for (Definition def : getConfig().getDefinition()) {
            // Check the specifics first
            for (String saddr : def.getSpecific()) {
                InetAddress addr = InetAddressUtils.addr(saddr);
                if (addr.equals(agentInetAddress)) {
                    return def;
                }
            }

            // Check the ranges
            for (Range rng : def.getRange()) {
                if (InetAddressUtils.isInetAddressInRange(InetAddressUtils.str(agentInetAddress), rng.getBegin(), rng.getEnd())) {
                    return def;
                }
            }

            // Check the matching IP expressions
            for (String ipMatch : def.getIpMatch()) {
                if (IPLike.matches(InetAddressUtils.str(agentInetAddress), ipMatch)) {
                    return def;
                }
            }
        }

        // No definition references the given agent address, use the defaults
        return new Definition(getConfig());
    }

    @Override
    public WSManEndpoint getEndpoint(InetAddress agentInetAddress) {
        return WSManConfigDao.getEndpoint(getAgentConfig(agentInetAddress), agentInetAddress);
    }

    @Override
    protected WsmanConfig translateConfig(WsmanConfig config) {
        return config;
    }
}
